#ifndef TESTS_COMMON_H_
#define TESTS_COMMON_H_

class Module *parsefile(const char *filename);

#endif
